@@ -28,6 +28,9 @@ import utils.file_utils as _cfu
 import utils.string_utils as _csu
 import utils.dict_utils as _obj
 import utils.list_utils as _lu
+
+import config as _config
+_log = _config.log
 # import colemen_file_utils as cfu
 # import colemen_string_utils as csu
 # import utils.object_utils as obj
@@ -345,7 +348,7 @@ class TableDataManager:
         '''
         return self.db.insert_data[self.insert_type][self.name]
 
-    def set_insert_data(self,data):
+    def set_insert_data(self,data,save_all=False):
         '''
             Set the insert data for the table.
 
@@ -431,7 +434,8 @@ class TableDataManager:
                 self.table.data['test_insert_data'] = cur_idata
             # self.db.insert_data[self.insert_type][self.name] = cur_idata
             self.db.insert_data[self.insert_type][self.name] = cur_idata
-            self.db.save()
+            if save_all:
+                self.db.save()
             # @Mstep [] save the insert json file and generate the insert SQL.
             return self.save(True)
 
@@ -630,15 +634,24 @@ def has_required_columns(table,row,print_errors=True):
         * @xxx [06-01-2022 15:20:28]: documentation for has_required_columns
     '''
 
-
+    alerts = []
     for k,v in row.items():
         if v is None:
             if allow_null(table,k) is False:
                 if print_errors:
-                    print(f"{k} is a required column in {table.name}, None was provided.")
-                return False
+                    msg = f"{k} is a required column in {table.name}, None was provided."
+                    alerts.append(msg)
+                    # print(f"{k} is a required column in {table.name}, None was provided.")
+    if len(alerts) > 0:
+        logged = []
+        for alert in alerts:
+            if alert not in logged:
+                count = _lu.count(alerts,alert)
+                if count > 1:
+                    _log(f"{count} - {alert}","error")
+                    logged.append(alert)
+        return False
     return True
-
 def insert_single_row(table,data):
     '''
         Insert a new row or rows into the default data json file.
